
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-06-08T11:23:38-0400",
 "dirty": false,
 "error": null,
 "full-revisionid": "000a82e612df727ace0888a8dd3c21c88b76fa6d",
 "version": "0.9.1"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
